.. _registration_chap:

Register for This Course
========================

Some Runestone books are open to the public. To save your work, however, you will need to register for an account on the Runestone server. This is also something students will have to do when you create a custom course from one of the eBooks, so you might as well learn how registration works right now.

First-time Registration
-----------------------

1. Open the following url in another tab: https://runestone.academy/runestone/default/user/register.  The form is pretty self-explanatory, except for the *Course Name* field. There is information about that on the right side. You can specify one of the strings that identify one of the public courses that the server knows about: thinkcspy, pythonds, etc.  Or you can enter the string for a custom course. 

2. Click *Register*

3. If you are on the login page instead at https://runestone.academy/runestone/default/user/login then click the *Register* button which is near the bottom of the page to get to the registration page.

Add an Additional Course
------------------------

When you are logged in and looking at an eBook, click on the person icon in the upper right and select *Change Course*.
That will take you to the course selection page.

Click on the *Add Another Course* button, which takes you to a page that looks a lot like the registration page. Don't change any of the fields there except *Course Name*. There, you can enter any string that identifies another course.

